@@ -1,7 +1,7 @@
 ;;; tex-info.el --- Support for editing Texinfo source.
 
 ;; Copyright (C) 1993, 1994, 1997, 2000, 2001,
-;;               2004, 2005 Free Software Foundation, Inc.
+;;               2004, 2005, 2006 Free Software Foundation, Inc.
 
 ;; Maintainer: auctex-devel@gnu.org
 ;; Keywords: tex
@@ -20,8 +20,8 @@
 
 ;; You should have received a copy of the GNU General Public License
 ;; along with AUCTeX; see the file COPYING.  If not, write to the Free
-;; Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-;; 02111-1307, USA.
+;; Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+;; 02110-1301, USA.
 
 ;;; Code:
 
@@ -411,75 +411,78 @@ value of `Texinfo-mode-hook'."
 				 (TeX-master-file nil nil t))) nil t)
 
   (TeX-add-symbols
-   '("appendix" "Title")
-   '("appendixsec" "Title")
-   '("appendixsection" "Title")
-   '("appendixsubsec" "Title")
-   '("appendixsubsubsec" "Title")
+   '("appendix" (TeX-arg-literal " ") (TeX-arg-free "Title"))
+   '("appendixsec" (TeX-arg-literal " ") (TeX-arg-free "Title"))
+   '("appendixsection" (TeX-arg-literal " ") (TeX-arg-free "Title"))
+   '("appendixsubsec" (TeX-arg-literal " ") (TeX-arg-free "Title"))
+   '("appendixsubsubsec" (TeX-arg-literal " ") (TeX-arg-free "Title"))
    '("asis")
-   '("author" "Author")
+   '("author" (TeX-arg-literal " ") (TeX-arg-free "Author"))
    '("b" "Text")
    '("bullet")
    '("bye")
-   '("c" "Comment")
-   '("center" "Line of text")
-   '("chapheading" "Title")
-   '("chapter" "Title")
-;; Texinfo doesn't like the brackets.
-;;   '("cindex" "Entry")
+   '("c" (TeX-arg-literal " ") (TeX-arg-free "Comment"))
+   '("center" (TeX-arg-literal " ") (TeX-arg-free "Line of text"))
+   '("chapheading" (TeX-arg-literal " ") (TeX-arg-free "Title"))
+   '("chapter" (TeX-arg-literal " ") (TeX-arg-free "Title"))
+   '("cindex" (TeX-arg-literal " ") (TeX-arg-free "Entry"))
    '("cite" "Reference")
-   '("clear" "Flag")
+   '("clear" (TeX-arg-literal " ") (TeX-arg-free "Flag"))
    '("code" "Sample code")
    '("command" "Command")
-   '("comment" "Comment")
+   '("comment" (TeX-arg-literal " ") (TeX-arg-free "Comment"))
    '("contents")
-   '("copyright")
-   '("defcodeindex" "Index name")
-   '("defindex" "Index name")
+   '("copyright" nil)
+   '("defcodeindex" (TeX-arg-literal " ") (TeX-arg-free "Index name"))
+   '("defindex" (TeX-arg-literal " ") (TeX-arg-free "Index name"))
    '("dfn" "Term")
    '("dmn" "Dimension")
-   '("dots")
+   '("dots" nil)
    '("emph" "Text")
    '("email" "Email address")
-   '("equiv")
+   '("equiv" nil)
    '("error")
    '("evenfooting" Texinfo-lrc-argument-hook)
    '("evenheading" Texinfo-lrc-argument-hook)
    '("everyfooting" Texinfo-lrc-argument-hook)
    '("everyheading" Texinfo-lrc-argument-hook)
-   '("exdent" "Line of text")
-   '("expansion")
+   '("exdent" (TeX-arg-literal " ") (TeX-arg-free "Line of text"))
+   '("expansion" nil)
    '("file" "Filename")
    '("finalout")
-   '("findex" "Entry")
+   '("findex" (TeX-arg-literal " ") (TeX-arg-free "Entry"))
    '("footnote" "Text of footnote")
-   '("footnotestyle" "Style")
+   '("footnotestyle" (TeX-arg-literal " ") (TeX-arg-free "Style"))
    '("group")
-   '("heading" "Title")
-   '("headings" "On off single double")
+   '("heading" (TeX-arg-literal " ") (TeX-arg-free "Title"))
+   ;; XXX: Would be nice with completion.
+   '("headings" (TeX-arg-literal " ") (TeX-arg-free "On off single double"))
    '("i" "Text")
    '("ignore")
-   '("include" "Filename")
+   '("include" (TeX-arg-literal " ") (TeX-arg-free "Filename"))
    '("inforef" "Node name" "Info file name")
    '("item")
    '("itemx")
    '("kbd" "Keyboard characters")
    '("key" "Key name")
-   '("kindex" "Entry")
-   '("majorheading"  "Title")
+   '("kindex" (TeX-arg-literal " ") (TeX-arg-free "Entry"))
+   '("majorheading" (TeX-arg-literal " ") (TeX-arg-free "Title"))
    '("menu")
    '("minus")
    '("need" "N")
-   '("node" "Name" "Next" "Previous" "Up")
+   '("node" (TeX-arg-literal " ") (TeX-arg-free "Name")
+     (TeX-arg-literal ", ") (TeX-arg-free "Next")
+     (TeX-arg-literal ", ") (TeX-arg-free "Previous")
+     (TeX-arg-literal ", ") (TeX-arg-free "Up"))
    '("noindent")
    '("oddfooting" Texinfo-lrc-argument-hook)
    '("oddheading" Texinfo-lrc-argument-hook)
    '("page")
-   '("paragraphindent" "Indent")
+   '("paragraphindent" (TeX-arg-literal " ") (TeX-arg-free "Indent"))
    '("pindex" "Entry")
-   '("point")
+   '("point" nil)
    '("print")
-   '("printindex" "Index name")
+   '("printindex" (TeX-arg-literal " ") (TeX-arg-free "Index name"))
    '("pxref" "Node name")
    '("r" "Text")
    '("ref" "Node name")
@@ -487,48 +490,68 @@ value of `Texinfo-mode-hook'."
    '("result")
    '("samp" "Text")
    '("sc" "Text")
-   '("section" "Title")
-   '("set" "Flag")
-   '("setchapternewpage" "On off odd")
-   '("setfilename" "Info file name")
-   '("settitle" "Title")
+   '("section" (TeX-arg-literal " ") (TeX-arg-free "Title"))
+   '("set" (TeX-arg-literal " ") (TeX-arg-free "Flag"))
+   ;; XXX: Would be nice with completion.
+   '("setchapternewpage" (TeX-arg-literal " ") (TeX-arg-free "On off odd"))
+   '("setfilename" (TeX-arg-literal " ") (TeX-arg-free "Info file name"))
+   '("settitle" (TeX-arg-literal " ") (TeX-arg-free "Title"))
    '("shortcontents")
    '("smallbook")
    '("sp" "N")
    '("strong" "Text")
-   '("subheading" "Title")
-   '("subsection" "Title")
-   '("subsubheading" "Title")
-   '("subsubsection" "Title")
-   '("subtitle" "Title")
+   '("subheading" (TeX-arg-literal " ") (TeX-arg-free "Title"))
+   '("subsection" (TeX-arg-literal " ") (TeX-arg-free "Title"))
+   '("subsubheading" (TeX-arg-literal " ") (TeX-arg-free "Title"))
+   '("subsubsection" (TeX-arg-literal " ") (TeX-arg-free "Title"))
+   '("subtitle" (TeX-arg-literal " ") (TeX-arg-free "Title"))
    '("summarycontents")
-   '("syncodeindex" "From index" "Into index")
-   '("synindex" "From index" "Into index")
+   '("syncodeindex" (TeX-arg-literal " ") (TeX-arg-free "From index")
+     (TeX-arg-literal " ") (TeX-arg-free "Into index"))
+   '("synindex" (TeX-arg-literal " ") (TeX-arg-free "From index")
+     (TeX-arg-literal " ") (TeX-arg-free "Into index"))
    '("t" "Text")
-   '("TeX")
+   '("TeX" nil)
    '("thischapter")
    '("thischaptername")
    '("thisfile")
    '("thispage")
-   '("tindex" "Entry")
-   '("title" "Title")
+   '("tindex" (TeX-arg-literal " ") (TeX-arg-free "Entry"))
+   '("title" (TeX-arg-literal " ") (TeX-arg-free "Title"))
    '("titlefont" "Text")
    '("titlepage")
-   '("today")
-   '("top" "Title")
-   '("unnumbered" "Title")
-   '("unnumberedsec" "Title")
-   '("unnumberedsubsec" "Title")
-   '("unnumberedsubsubsec" "Title")
+   '("today" nil)
+   '("top" (TeX-arg-literal " ") (TeX-arg-free "Title"))
+   '("unnumbered" (TeX-arg-literal " ") (TeX-arg-free "Title"))
+   '("unnumberedsec" (TeX-arg-literal " ") (TeX-arg-free "Title"))
+   '("unnumberedsubsec" (TeX-arg-literal " ") (TeX-arg-free "Title"))
+   '("unnumberedsubsubsec" (TeX-arg-literal " ") (TeX-arg-free "Title"))
    '("value" "Flag")
    '("var" "Metasyntactic variable")
-   '("vindex" "Entry")
-   '("vskip" "Amount")
+   '("vindex" (TeX-arg-literal " ") (TeX-arg-free "Entry"))
+   '("vskip" (TeX-arg-literal " ") (TeX-arg-free "Amount"))
    '("w" "Text")
    '("xref" "Node name"))
   
   (TeX-run-mode-hooks 'text-mode-hook 'Texinfo-mode-hook)
   (TeX-set-mode-name))
+
+(defcustom Texinfo-clean-intermediate-suffixes nil
+  "List of regexps matching suffixes of files to be deleted.
+The regexps will be anchored at the end of the file name to be matched,
+i.e. you do _not_ have to cater for this yourself by adding \\\\' or $."
+  :type '(repeat regexp)
+  :group 'TeX-command)
+
+(defcustom Texinfo-clean-output-suffixes
+  ;; See `man texi2html' for the HTML stuff.
+  '("\\.info\\(-[0-9]+\\)?" "\\.dvi" "\\.pdf" "\\.ps" "\\.html"
+    "_toc\\.html" "_fot\\.html" "_abt\\.html" "_[0-9]+\\.html" "_l2h_img.+")
+  "List of regexps matching suffixes of files to be deleted.
+The regexps will be anchored at the end of the file name to be matched,
+i.e. you do _not_ have to cater for this yourself by adding \\\\' or $."
+  :type '(repeat regexp)
+  :group 'TeX-command)
   
 (provide 'tex-info)
   
